![MDS3](https://ouroboroscoding.s3.us-east-2.amazonaws.com/logos/MDs3_163.png)

MySQL Dump to S3

## Description
Runs MySQL dump to fetch all data in one or more databases, then stores that data as a private object in AWS S3

## Install

```console
foo@bar:~$ pip install mds3
```

## Run

```console
foo@bar:~$ mds3
```

## License

MIT License